<script setup lang="ts">
import { ref } from 'vue';
import Alert from '~/components/ui/Alert.vue'
import Layout from '~/components/ui/Layout.vue'
import Spacer from '~/components/ui/layout/Spacer.vue'
import Input from '~/components/ui/Input.vue'
import Card from '~/components/ui/Card.vue'

const size = ref(32)
</script>

<style>
  .preview {
    padding:16px 0;
    flex-grow:1;
  }
</style>

# Spacer

Add a 16px gap between adjacent items.

##### Without spacer:

<Layout flex>

```vue-html
<Alert color="green">A</Alert>
<Alert color="red">B</Alert>
```

<div class="preview">

<Alert color="green">A</Alert>
<Alert color="red">B</Alert>

</div>

</Layout>

##### With spacer:

<Layout flex>

```vue-html{2}
<Alert color="green">A</Alert>
<Spacer/>
<Alert color="red">B</Alert>
```

<div class="preview">
<Alert color="green">A</Alert>
<Spacer/>
<Alert color="red">B</Alert>
</div>

</Layout>

##### Spacers can also be added for horizontal space:

<Layout flex>

```vue-html{4}
<Layout flex>
  <Alert color="blue">A</Alert>
  <Alert color="green">A</Alert>
  <Spacer/>
  <Alert color="red">B</Alert>
</Layout>
```

<div class="preview">
<Layout flex>
<Alert color="blue">A</Alert>
<Alert color="green">A</Alert>
<Spacer/>
<Alert color="red">B</Alert>
</Layout>
</div>
</Layout>

## Modify the size of a Spacer

<Layout flex>

```vue
<script setup>
const size = ref(1);
</script>

<template>
  <Input v-model="size" type="range" />

  <Alert color="blue">A</Alert>
  <Alert color="green">A</Alert>
  <Spacer :size="size" />
  <Alert color="red">B</Alert>
</template>
```

<div class="preview">
  <Input v-model="size" type="range" style="writing-mode: vertical-lr; direction: rtl"/>
  {{ size }}px
</div>
<div class="preview">
  <Alert color="blue">A</Alert>
  <Spacer :size="size" />
  <Alert color="red">B</Alert>
</div>
</Layout>

## Make the Spacer elastic

<Layout flex>

```vue-html
<Layout flex style="height:30em;">
  <Input v-model="size"
    type="range"
    style="writing-mode: vertical-lr; height:100%"
  />

  <Layout stack no-gap
    :style="{ height: size + '%' }"
  >
    <Alert>A</Alert>
    <Spacer grow title="grow" />
    <Alert>B</Alert>
    <Alert>C</Alert>
    <Spacer shrink title="shrink" />
    <Alert>D</Alert>
    <Spacer grow shrink title="grow shrink" />
    <Alert>E</Alert>
  </Layout>
</Layout>
```

<div class="preview" style="flex-wrap:no-wrap">
<Layout flex style="height:30em">

<Input v-model="size" type="range" style="writing-mode: vertical-lr; height:100%"><template #input-right>{{ size }}%</template></Input>

<Layout stack no-gap :style="{ height: size + '%'}">
  <Alert>A</Alert>
  <Spacer grow title="grow" />
  <Alert>B</Alert>
  <Alert>C</Alert>
  <Spacer shrink title="shrink" />
  <Alert>D</Alert>
  <Spacer grow shrink title="grow shrink" />
  <Alert>E</Alert>
</Layout>

</Layout>

</div>
</Layout>
